describe('Create, edit, and delete a Basic Page with Mercury Editor.', () => {
  it('Creates, edits, and deletes a new Basic Page.', () => {
    // Clear the cache.
    cy.drush('cr');
    // Login as admin.
    cy.loginUserByUid(1);
    // Create a new page.
    cy.visit('/node/add/page');
    cy.get('#edit-title-0-value').clear().type('-- Test page --');
    // Tests that syncing the title field works.
    cy.iframe('#me-preview').find('.page-title').contains(' -- Test page --');
    cy.iframe('#me-preview').find('.lpb-btn--add').trigger('click');

    // Make sure all the components are available.
    cy.iframe('#me-preview').get('.lpb-component-list')
      .should('contain', 'Layout')
      .and('contain', 'Section')
      .and('contain', 'Default')
      .and('contain', 'Text')
      .and('contain', 'Image')
      .and('contain', 'Image Gallery')
      .and('contain', 'Video')
      .and('contain', 'Card');

    // Add a 2-column layout.
    cy.get('a').contains('Section').click();
    cy.get('input[value="layout_twocolumn_halves"] + label').click();
    cy.get('.me-dialog__buttonpane .lpb-btn--save').click();

    // Add a text paragraph in first column.
    cy.iframe('#me-preview').find('.l__region.l__primary .lpb-btn--add').trigger('click');
    cy.get('a').contains('Text').click();
    cy.get('.ck-content[contenteditable=true]').then(el => {
      const editor = el[0].ckeditorInstance
      editor.setData('First')
    });
    cy.get('.me-dialog__buttonpane .lpb-btn--save').click();

    // Add a text paragraph in second column.
    cy.iframe('#me-preview').find('.l__region.l__secondary .lpb-btn--add').trigger('click');
    cy.get('a').contains('Text').click();

    cy.get('.ck-content[contenteditable=true]').then(el => {
      const editor = el[0].ckeditorInstance
      editor.setData('Second')
    });
    cy.get('.me-dialog__buttonpane .lpb-btn--save').click();

    // Save the page.
    cy.get('#me-save-btn').click();
    cy.get('#me-done-btn').click();
    cy.get('.l__primary').should('contain', 'First');
    cy.get('.l__secondary').should('contain', 'Second');

    // Edit the page.
    cy.get('a[title="Edit Page"]').click();

    // Edit the first paragraph.
    cy.iframe('#me-preview').find('.l__region.l__primary [data-uuid]').trigger('mouseover');
    cy.iframe('#me-preview').find('.l__region.l__primary .lpb-edit').trigger('click');
    cy.get('.ck-content[contenteditable=true]').then(el => {
      const editor = el[0].ckeditorInstance
      editor.setData('First - edited')
    });
    cy.wait(500);
    cy.get('.me-dialog__buttonpane .lpb-btn--save').click();
    cy.iframe('#me-preview').find('.l__primary').should('contain', 'First - edited');

    // Edit the second paragraph.
    cy.iframe('#me-preview').find('.l__region.l__secondary [data-uuid]').trigger('mouseover');
    cy.iframe('#me-preview').find('.l__region.l__secondary .lpb-edit').trigger('click');
    cy.get('.ck-content[contenteditable=true]').then(el => {
      const editor = el[0].ckeditorInstance
      editor.setData('Second - edited')
    });
    cy.wait(500);
    cy.get('.me-dialog__buttonpane .lpb-btn--save').click();
    cy.iframe('#me-preview').find('.l__secondary').should('contain', 'Second - edited');

    // Add a 3-column layout.
    cy.iframe('#me-preview').find('[data-type="section"] > .lpb-btn--add.after').trigger('click');
    cy.get('a').contains('Section').click();
    cy.get('input[value="layout_threecolumn_thirds"] + label').click();
    cy.get('.me-dialog__buttonpane .lpb-btn--save').click();

    // Add a text paragraph in bottom left column.
    cy.iframe('#me-preview').find('.l--layout-threecolumn-thirds .l__primary .lpb-btn--add').trigger('click');
    cy.get('a').contains('Text').click();
    cy.get('.ck-content[contenteditable=true]').then(el => {
      const editor = el[0].ckeditorInstance
      editor.setData('Bottom left')
    });
    cy.get('.me-dialog__buttonpane .lpb-btn--save').click();
    cy.wait(500);

    // A a text paragraph in the bottom middle column.
    cy.iframe('#me-preview').find('.l--layout-threecolumn-thirds .l__secondary .lpb-btn--add').trigger('click');
    cy.get('a').contains('Text').click();
    cy.get('.ck-content[contenteditable=true]').then(el => {
      const editor = el[0].ckeditorInstance
      editor.setData('Bottom middle')
    });
    cy.get('.me-dialog__buttonpane .lpb-btn--save').click();
    cy.wait(500);

    // A a text paragraph in the bottom right column.
    cy.iframe('#me-preview').find('.l--layout-threecolumn-thirds .l__tertiary .lpb-btn--add').trigger('click');
    cy.get('a').contains('Text').click();
    cy.get('.ck-content[contenteditable=true]').then(el => {
      const editor = el[0].ckeditorInstance
      editor.setData('Bottom right')
    });
    cy.get('.me-dialog__buttonpane .lpb-btn--save').click();
    cy.wait(500);

    cy.get('#me-save-btn').click();
    cy.get('#me-done-btn').click();
    cy.get('.l--layout-twocolumn-halves .l__primary').should('contain', 'First - edited');
    cy.get('.l--layout-twocolumn-halves .l__secondary').should('contain', 'Second - edited');
    cy.get('.l--layout-threecolumn-thirds .l__primary').should('contain', 'Bottom left');
    cy.get('.l--layout-threecolumn-thirds .l__secondary').should('contain', 'Bottom middle');
    cy.get('.l--layout-threecolumn-thirds .l__tertiary').should('contain', 'Bottom right');

    // All done, delete the page.
    cy.get('a').contains('Delete').click();
    // Confirm the deletion.
    cy.get('.button--primary:visible').contains('Delete').click();
  });
});
